@@ -13,6 +13,7 @@ later, but that will cause problems--the code will get executed twice:
 .. seealso:: http://click.pocoo.org/5/setuptools/#setuptools-integration
 """
 
+import json
 import logging
 import os
 import sys
@@ -28,10 +29,10 @@ from .canonicalize import to_bel_script
 from .constants import get_cache_connection
 from .examples import braf_graph, egf_graph, homology_graph, sialic_acid_graph, statin_graph
 from .io import (
-    from_bel_script, from_pickle, to_bel_commons, to_edgelist, to_graphml, to_gsea, to_neo4j, to_nodelink_file,
-    to_pickle, to_sif, to_tsv,
+    from_bel_script, from_pickle, load, to_bel_commons, to_edgelist, to_graphml, to_gsea, to_neo4j,
+    to_nodelink_file, to_pickle, to_sif, to_tsv,
 )
-from .io.bel_commons_client import _get_host
+from .io.bel_commons_client import _get_host, _get_password, _get_user
 from .manager import Manager
 from .manager.database_io import to_database
 from .manager.models import Edge, Namespace, Node
@@ -55,7 +56,22 @@ connection_option = click.option(
     help='Database connection string.',
 )
 
-host_option = click.option('--host', help='URL of BEL Commons. Defaults to {}'.format(_get_host()))
+host_option = click.option(
+    '--host',
+    default=_get_host(), show_default=True,
+    help='URL of BEL Commons.',
+)
+user_option = click.option(
+    '--user',
+    default=_get_user, show_default=True, prompt=True,
+    help='User for BEL Commons',
+)
+password_option = click.option(
+    '--password',
+    default=_get_password, show_default=True,
+    prompt=True, hide_input=True,
+    help='Password for BEL Commons',
+)
 
 
 def _from_pickle_callback(ctx, param, file):
@@ -83,6 +99,12 @@ graph_pickle_argument = click.argument(
     callback=_from_pickle_callback,
 )
 
+graph_argument = click.argument(
+    'graph',
+    metavar='path',
+    callback=lambda _, __, path: load(path),
+)
+
 
 @with_plugins(iter_entry_points('pybel.cli_plugins'))
 @click.group(help="PyBEL CLI on {}".format(sys.executable))
@@ -213,12 +235,15 @@ def insert(manager, graph: BELGraph):
 
 
 @main.command()
-@graph_pickle_argument
+@graph_argument
 @host_option
-def post(graph: BELGraph, host: str):
+@user_option
+@password_option
+def upload(graph: BELGraph, host: str, user: str, password: str):
     """Upload a graph to BEL Commons."""
-    resp = to_bel_commons(graph, host=host)
+    resp = to_bel_commons(graph, host=host, user=user, password=password)
     resp.raise_for_status()
+    click.echo(json.dumps(resp.json()))
 
 
 @main.command()
