@@ -72,7 +72,7 @@ CITATION_DATE = 'date'
 #: Represents the key for the citation authors in a citation dictionary
 CITATION_AUTHORS = 'authors'
 #: Represents the key for the citation comment in a citation dictionary
-CITATION_JOURNAL = 'db_name'
+CITATION_JOURNAL = 'journal'
 #: Represents the key for the optional PyBEL citation volume entry in a citation dictionary
 CITATION_VOLUME = 'volume'
 #: Represents the key for the optional PyBEL citation issue entry in a citation dictionary
@@ -256,6 +256,8 @@ CITATION = 'citation'
 EVIDENCE = 'evidence'
 #: The key for an internal edge data dictionary for the annotations dictionary
 ANNOTATIONS = 'annotations'
+#: The key for free annotations
+FREE_ANNOTATIONS = 'free_annotations'
 #: The key for an internal edge data dictionary for the subject modifier dictionary
 SUBJECT = 'subject'
 #: The key for an internal edge data dictionary for the object modifier dictionary
@@ -552,8 +554,5 @@ PYBEL_REMOTE_HOST = 'PYBEL_REMOTE_HOST'
 PYBEL_REMOTE_USER = 'PYBEL_REMOTE_USER'
 PYBEL_REMOTE_PASSWORD = 'PYBEL_REMOTE_PASSWORD'  # noqa: S105
 
-#: The default location of PyBEL Web
-DEFAULT_SERVICE_URL = 'https://bel-commons.scai.fraunhofer.de'
-
 PYBEL_PUBMED = '29048466'
 SET_CITATION_FMT = 'SET Citation = {{"{}", "{}"}}'
