@@ -3,15 +3,15 @@
 """Convenient dictionaries for mapping constants to DSL classes."""
 
 from .node_classes import (
-    Abundance, BiologicalProcess, ComplexAbundance, CompositeAbundance, Gene, GeneFusion, MicroRna, NamedComplexAbundance,
-    Pathology, Protein, ProteinFusion, Rna, RnaFusion,
+    Abundance, BiologicalProcess, ComplexAbundance, CompositeAbundance, Gene, GeneFusion, MicroRna,
+    NamedComplexAbundance, Pathology, Population, Protein, ProteinFusion, Rna, RnaFusion,
 )
-from ..constants import ABUNDANCE, BIOPROCESS, COMPLEX, COMPOSITE, GENE, MIRNA, PATHOLOGY, PROTEIN, RNA
+from ..constants import ABUNDANCE, BIOPROCESS, COMPLEX, COMPOSITE, GENE, MIRNA, PATHOLOGY, POPULATION, PROTEIN, RNA
 
 __all__ = [
     'FUNC_TO_DSL',
     'FUNC_TO_FUSION_DSL',
-    'FUNC_TO_LIST_DSL'
+    'FUNC_TO_LIST_DSL',
 ]
 
 FUNC_TO_DSL = {
@@ -23,6 +23,7 @@ FUNC_TO_DSL = {
     BIOPROCESS: BiologicalProcess,
     COMPLEX: NamedComplexAbundance,
     ABUNDANCE: Abundance,
+    POPULATION: Population,
 }
 
 FUNC_TO_FUSION_DSL = {
@@ -33,5 +34,5 @@ FUNC_TO_FUSION_DSL = {
 
 FUNC_TO_LIST_DSL = {
     COMPLEX: ComplexAbundance,
-    COMPOSITE: CompositeAbundance
+    COMPOSITE: CompositeAbundance,
 }
