@@ -2,12 +2,14 @@
 
 """This directory contains example networks, precompiled as BEL graphs that are appropriate to use in examples."""
 
+from .ampk_example import ampk_graph
 from .braf_example import braf_graph
 from .egf_example import egf_graph
 from .homology_example import homology_graph
 from .sialic_acid_example import sialic_acid_graph
 from .statin_example import statin_graph
 from .tloc_example import ras_tloc_graph
+from .vegf_example import vegf_graph
 
 __all__ = [
     'egf_graph',
@@ -16,4 +18,6 @@ __all__ = [
     'braf_graph',
     'homology_graph',
     'ras_tloc_graph',
+    'ampk_graph',
+    'vegf_graph',
 ]
