@@ -8,9 +8,11 @@ ability of other existing software is excluded due the immaturity of the BEL to
 """
 
 from .api import dump, load
+from .aws import from_s3, to_s3
 from .bel_commons_client import from_bel_commons, to_bel_commons
 from .biodati_client import from_biodati, to_biodati
 from .cx import from_cx, from_cx_file, from_cx_gz, from_cx_jsons, to_cx, to_cx_file, to_cx_gz, to_cx_jsons
+from .emmaa import from_emmaa
 from .extras import to_csv, to_gsea, to_sif
 from .fraunhofer_orientdb import from_fraunhofer_orientdb
 from .gpickle import from_bytes, from_pickle, to_bytes, to_pickle
@@ -29,6 +31,7 @@ from .jgif import (
     from_cbn_jgif, from_cbn_jgif_file, from_jgif, from_jgif_file, from_jgif_gz, from_jgif_jsons, post_jgif, to_jgif,
     to_jgif_file, to_jgif_gz, to_jgif_jsons,
 )
+from .jupyter import to_jupyter, to_jupyter_str
 from .lines import from_bel_script, from_bel_script_url
 from .neo4j import to_neo4j
 from .nodelink import (
