@@ -25,28 +25,30 @@ __all__ = [
     'parse_lines',
 ]
 
-log = logging.getLogger(__name__)
-parse_log = logging.getLogger('pybel.parser')
+logger = logging.getLogger(__name__)
+parser_logger = logging.getLogger('pybel.parser')
 
 METADATA_LINE_RE = re.compile(r"(SET\s+DOCUMENT|DEFINE\s+NAMESPACE|DEFINE\s+ANNOTATION)")
 LOG_FMT = '%d:%d %s %s'
 LOG_FMT_PATH = '%s:%d:%d %s %s'
 
 
-def parse_lines(graph: BELGraph,
-                lines: Iterable[str],
-                manager: Optional[Manager] = None,
-                allow_nested: bool = False,
-                citation_clearing: bool = True,
-                use_tqdm: bool = False,
-                tqdm_kwargs: Optional[Mapping[str, Any]] = None,
-                no_identifier_validation: bool = False,
-                disallow_unqualified_translocations: bool = False,
-                allow_redefinition: bool = False,
-                allow_definition_failures: bool = False,
-                allow_naked_names: bool = False,
-                required_annotations: Optional[List[str]] = None,
-                ):
+def parse_lines(
+    graph: BELGraph,
+    lines: Iterable[str],
+    manager: Optional[Manager] = None,
+    disallow_nested: bool = False,
+    citation_clearing: bool = True,
+    use_tqdm: bool = False,
+    tqdm_kwargs: Optional[Mapping[str, Any]] = None,
+    no_identifier_validation: bool = False,
+    disallow_unqualified_translocations: bool = False,
+    allow_redefinition: bool = False,
+    allow_definition_failures: bool = False,
+    allow_naked_names: bool = False,
+    required_annotations: Optional[List[str]] = None,
+    upgrade_urls: bool = False,
+) -> None:
     """Parse an iterable of lines into this graph.
 
     Delegates to :func:`parse_document`, :func:`parse_definitions`, and :func:`parse_statements`.
@@ -54,13 +56,14 @@ def parse_lines(graph: BELGraph,
     :param graph: A BEL graph
     :param lines: An iterable over lines of BEL script
     :param manager: A PyBEL database manager
-    :param allow_nested: If true, turns off nested statement failures
+    :param disallow_nested: If true, turns on nested statement failures
     :param citation_clearing: Should :code:`SET Citation` statements clear evidence and all annotations?
                                    Delegated to :class:`pybel.parser.ControlParser`
     :param use_tqdm: Use :mod:`tqdm` to show a progress bar?
     :param tqdm_kwargs: Keywords to pass to ``tqdm``
     :param disallow_unqualified_translocations: If true, allow translocations without TO and FROM clauses.
     :param required_annotations: Annotations that are required for all statements
+    :param upgrade_urls: Automatically upgrade old namespace URLs. Defaults to false.
 
     .. warning::
 
@@ -81,6 +84,7 @@ def parse_lines(graph: BELGraph,
         manager,
         allow_redefinition=allow_redefinition,
         skip_validation=no_identifier_validation,
+        upgrade_urls=upgrade_urls,
     )
 
     parse_document(
@@ -101,13 +105,13 @@ def parse_lines(graph: BELGraph,
     bel_parser = BELParser(
         graph=graph,
         # terminologies
-        namespace_to_term=metadata_parser.namespace_to_term,
+        namespace_to_term_to_encoding=metadata_parser.namespace_to_term_to_encoding,
         namespace_to_pattern=metadata_parser.namespace_to_pattern,
         annotation_to_term=metadata_parser.annotation_to_term,
         annotation_to_pattern=metadata_parser.annotation_to_pattern,
         annotation_to_local=metadata_parser.annotation_to_local,
         # language settings
-        allow_nested=allow_nested,
+        disallow_nested=disallow_nested,
         citation_clearing=citation_clearing,
         skip_validation=no_identifier_validation,
         allow_naked_names=allow_naked_names,
@@ -123,13 +127,14 @@ def parse_lines(graph: BELGraph,
         tqdm_kwargs=tqdm_kwargs,
     )
 
-    log.info('Network has %d nodes and %d edges', graph.number_of_nodes(), graph.number_of_edges())
+    logger.info('Network has %d nodes and %d edges', graph.number_of_nodes(), graph.number_of_edges())
 
 
-def parse_document(graph: BELGraph,
-                   enumerated_lines: Iterable[Tuple[int, str]],
-                   metadata_parser: MetadataParser,
-                   ) -> None:
+def parse_document(
+    graph: BELGraph,
+    enumerated_lines: Iterable[Tuple[int, str]],
+    metadata_parser: MetadataParser,
+) -> None:
     """Parse the lines in the document section of a BEL script."""
     parse_document_start_time = time.time()
 
@@ -157,16 +162,17 @@ def parse_document(graph: BELGraph,
 
     graph.document.update(metadata_parser.document_metadata)
 
-    log.info('Finished parsing document section in %.02f seconds', time.time() - parse_document_start_time)
+    logger.info('Finished parsing document section in %.02f seconds', time.time() - parse_document_start_time)
 
 
-def parse_definitions(graph: BELGraph,
-                      enumerated_lines: Iterable[Tuple[int, str]],
-                      metadata_parser: MetadataParser,
-                      allow_failures: bool = False,
-                      use_tqdm: bool = False,
-                      tqdm_kwargs: Optional[Mapping[str, Any]] = None,
-                      ) -> None:
+def parse_definitions(
+    graph: BELGraph,
+    enumerated_lines: Iterable[Tuple[int, str]],
+    metadata_parser: MetadataParser,
+    allow_failures: bool = False,
+    use_tqdm: bool = False,
+    tqdm_kwargs: Optional[Mapping[str, Any]] = None,
+) -> None:
     """Parse the lines in the definitions section of a BEL script.
 
     :param graph: A BEL graph
@@ -191,11 +197,12 @@ def parse_definitions(graph: BELGraph,
         try:
             metadata_parser.parseString(line, line_number=line_number)
         except (InconsistentDefinitionError, ResourceError) as e:
-            parse_log.exception(LOG_FMT, line_number, 0, e.__class__.__name__, line)
+            parser_logger.exception(LOG_FMT, line_number, 0, e.__class__.__name__, line)
             raise e
         except OperationalError as e:
-            parse_log.warning('Need to upgrade database. See '
-                              'http://pybel.readthedocs.io/en/latest/installation.html#upgrading')
+            parser_logger.warning(
+                'Need to upgrade database. See http://pybel.readthedocs.io/en/latest/installation.html#upgrading',
+            )
             raise e
         except Exception as e:
             if not allow_failures:
@@ -215,17 +222,17 @@ def parse_definitions(graph: BELGraph,
         for keyword, pattern in metadata_parser.annotation_to_pattern.items()
     })
     graph.annotation_list.update(metadata_parser.annotation_to_local)
-    graph.uncached_namespaces.update(metadata_parser.uncachable_namespaces)
 
-    log.info('Finished parsing definitions section in %.02f seconds', time.time() - parse_definitions_start_time)
+    logger.info('Finished parsing definitions section in %.02f seconds', time.time() - parse_definitions_start_time)
 
 
-def parse_statements(graph: BELGraph,
-                     enumerated_lines: Iterable[Tuple[int, str]],
-                     bel_parser: BELParser,
-                     use_tqdm: bool = False,
-                     tqdm_kwargs: Optional[Mapping[str, Any]] = None,
-                     ) -> None:
+def parse_statements(
+    graph: BELGraph,
+    enumerated_lines: Iterable[Tuple[int, str]],
+    bel_parser: BELParser,
+    use_tqdm: bool = False,
+    tqdm_kwargs: Optional[Mapping[str, Any]] = None,
+) -> None:
     """Parse a list of statements from a BEL Script.
 
     :param graph: A BEL graph
@@ -257,15 +264,18 @@ def parse_statements(graph: BELGraph,
             _log_parse_exception(graph, exc)
             graph.add_warning(exc, bel_parser.get_annotations())
         except Exception:
-            parse_log.exception(LOG_FMT, line_number, 0, 'General Failure', line)
+            parser_logger.exception(LOG_FMT, line_number, 0, 'General Failure', line)
             raise
 
-    log.info('Parsed statements section in %.02f seconds with %d warnings', time.time() - parse_statements_start_time,
-             len(graph.warnings))
+    logger.info(
+        'Parsed statements section in %.02f seconds with %d warnings',
+        time.time() - parse_statements_start_time,
+        len(graph.warnings),
+    )
 
 
 def _log_parse_exception(graph: BELGraph, exc: BELParserWarning):
     if graph.path:
-        parse_log.error(LOG_FMT_PATH, graph.path, exc.line_number, exc.position, exc.__class__.__name__, exc)
+        parser_logger.error(LOG_FMT_PATH, graph.path, exc.line_number, exc.position, exc.__class__.__name__, exc)
     else:
-        parse_log.error(LOG_FMT, exc.line_number, exc.position, exc.__class__.__name__, exc)
+        parser_logger.error(LOG_FMT, exc.line_number, exc.position, exc.__class__.__name__, exc)
