@@ -5,8 +5,8 @@
 from tqdm import tqdm
 
 from ..constants import (
-    ANNOTATIONS, CITATION, CITATION_REFERENCE, CITATION_TYPE, EVIDENCE, FUSION, MEMBERS, NAMESPACE, OBJECT,
-    RELATION, SUBJECT, VARIANTS,
+    ANNOTATIONS, CITATION, CITATION_DB, CITATION_IDENTIFIER, EVIDENCE, FUSION, MEMBERS, NAMESPACE, OBJECT, RELATION,
+    SUBJECT, VARIANTS,
 )
 from ..utils import flatten_dict
 
@@ -15,7 +15,7 @@ __all__ = [
 ]
 
 
-def to_neo4j(graph, neo_connection, use_tqdm=False):
+def to_neo4j(graph, neo_connection, use_tqdm: bool = False):
     """Upload a BEL graph to a Neo4j graph database using :mod:`py2neo`.
 
     :param pybel.BELGraph graph: A BEL Graph
@@ -81,7 +81,7 @@ def to_neo4j(graph, neo_connection, use_tqdm=False):
 
         citation = d.pop(CITATION, None)
         if citation:
-            attrs[CITATION] = '{}:{}'.format(citation[CITATION_TYPE], citation[CITATION_REFERENCE])
+            attrs[CITATION] = '{}:{}'.format(citation[CITATION_DB], citation[CITATION_IDENTIFIER])
 
         if EVIDENCE in d:
             attrs[EVIDENCE] = d[EVIDENCE]
