@@ -6,11 +6,11 @@ import datetime
 from typing import Iterable, List, Optional, Union
 
 from sqlalchemy import and_, or_
+from sqlalchemy.orm import aliased
 
 from .lookup_manager import LookupManager
 from .models import Author, Citation, Edge, Evidence, Namespace, NamespaceEntry, Node
 from ..constants import CITATION_TYPE_PUBMED
-from ..dsl import BaseEntity
 from ..struct import BELGraph
 from ..utils import parse_datetime
 
@@ -37,21 +37,13 @@ class QueryManager(LookupManager):
         """Count the number of nodes in the database."""
         return self._count_model(Node)
 
-    def get_dsl_by_hash(self, node_hash: str) -> Optional[BaseEntity]:
-        """Look up a node by the hash and returns the corresponding PyBEL node tuple."""
-        node = self.get_node_by_hash(node_hash)
-
-        if node is None:
-            return
-
-        return node.to_json()
-
-    def query_nodes(self,
-                    bel: Optional[str] = None,
-                    type: Optional[str] = None,
-                    namespace: Optional[str] = None,
-                    name: Optional[str] = None,
-                    ) -> List[Node]:
+    def query_nodes(
+        self,
+        bel: Optional[str] = None,
+        type: Optional[str] = None,
+        namespace: Optional[str] = None,
+        name: Optional[str] = None,
+    ) -> List[Node]:
         """Query nodes in the database.
 
         :param bel: BEL term that describes the biological entity. e.g. ``p(HGNC:APP)``
@@ -62,21 +54,21 @@ class QueryManager(LookupManager):
         q = self.session.query(Node)
 
         if bel:
-            q = q.filter(Node.bel.like(bel))
+            q = q.filter(Node.bel.contains(bel))
 
         if type:
-            q = q.filter(Node.type.like(type))
+            q = q.filter(Node.type == type)
 
         if namespace or name:
             q = q.join(NamespaceEntry)
 
             if namespace:
-                q = q.join(Namespace).filter(Namespace.keyword.like(namespace))
+                q = q.join(Namespace).filter(Namespace.keyword.contains(namespace))
 
             if name:
-                q = q.filter(NamespaceEntry.name.like(name))
+                q = q.filter(NamespaceEntry.name.contains(name))
 
-        return q.all()
+        return q
 
     def count_edges(self) -> int:
         """Count the number of edges in the database."""
@@ -102,7 +94,7 @@ class QueryManager(LookupManager):
 
         :param bel: A BEL string to use as a search
         """
-        return self.session.query(Edge).filter(Edge.bel.like(bel)).all()
+        return self.session.query(Edge).filter(Edge.bel.like(bel))
 
     def get_edges_with_annotation(self, annotation: str, value: str) -> List[Edge]:
         """Search edges with the given annotation/value pair."""
@@ -115,15 +107,18 @@ class QueryManager(LookupManager):
         """See usage in self.query_edges."""
         return query.join(Node, edge_node_id == Node.id).filter(Node.type == node_type)
 
-    def query_edges(self,
-                    bel: Optional[str] = None,
-                    source_function: Optional[str] = None,
-                    source: Union[None, str, Node] = None,
-                    target_function: Optional[str] = None,
-                    target: Union[None, str, Node] = None,
-                    relation: Optional[str] = None,
-                    ) -> List[Edge]:
-        """Query edges in the database.
+    def query_edges(
+        self,
+        bel: Optional[str] = None,
+        source_function: Optional[str] = None,
+        source: Union[None, str, Node] = None,
+        target_function: Optional[str] = None,
+        target: Union[None, str, Node] = None,
+        relation: Optional[str] = None,
+    ):
+        """Return a query over the edges in the database.
+
+        Usually this means that you should call ``list()`` or ``.all()`` on this result.
 
         :param bel: BEL statement that represents the desired edge.
         :param source_function: Filter source nodes with the given BEL function
@@ -141,17 +136,23 @@ class QueryManager(LookupManager):
             query = query.filter(Edge.relation.like(relation))
 
         if source_function:
-            query = self._add_edge_function_filter(query, Edge.source_id, source_function)
+            source_node_table = aliased(Node)
+            query = query \
+                .join(source_node_table, Edge.source_id == source_node_table.id) \
+                .filter(source_node_table.type == source_function)
 
         if target_function:
-            query = self._add_edge_function_filter(query, Edge.target_id, target_function)
+            target_node_table = aliased(Node)
+            query = query \
+                .join(target_node_table, Edge.target_id == target_node_table.id) \
+                .filter(target_node_table.type == target_function)
 
         if source:
             if isinstance(source, str):
                 source = self.query_nodes(bel=source)
-                if len(source) == 0:
+                if source.count() == 0:
                     return []
-                source = source[0]  # FIXME what if this matches multiple?
+                source = source.first()  # FIXME what if this matches multiple?
                 query = query.filter(Edge.source == source)
             elif isinstance(source, Node):
                 query = query.filter(Edge.source == source)
@@ -160,7 +161,7 @@ class QueryManager(LookupManager):
 
         if target:
             if isinstance(target, str):
-                targets = self.query_nodes(bel=target)
+                targets = self.query_nodes(bel=target).all()
                 target = targets[0]  # FIXME what if this matches multiple?
                 query = query.filter(Edge.target == target)
             elif isinstance(target, Node):
@@ -168,20 +169,21 @@ class QueryManager(LookupManager):
             else:
                 raise TypeError('Invalid type of {}: {}'.format(target, target.__class__.__name__))
 
-        return query.all()
+        return query
 
-    def query_citations(self,
-                        type: Optional[str] = None,
-                        reference: Optional[str] = None,
-                        name: Optional[str] = None,
-                        author: Union[None, str, List[str]] = None,
-                        date: Union[None, str, datetime.date] = None,
-                        evidence_text: Optional[str] = None,
-                        ) -> List[Citation]:
+    def query_citations(
+        self,
+        db: Optional[str] = None,
+        db_id: Optional[str] = None,
+        name: Optional[str] = None,
+        author: Union[None, str, List[str]] = None,
+        date: Union[None, str, datetime.date] = None,
+        evidence_text: Optional[str] = None,
+    ) -> List[Citation]:
         """Query citations in the database.
 
-        :param type: Type of the citation. e.g. PubMed
-        :param reference: The identifier used for the citation. e.g. PubMed_ID
+        :param db: Type of the citation. e.g. PubMed
+        :param db_id: The identifier used for the citation. e.g. PubMed_ID
         :param name: Title of the citation.
         :param author: The name or a list of names of authors participated in the citation.
         :param date: Publishing date of the citation.
@@ -198,11 +200,11 @@ class QueryManager(LookupManager):
             else:
                 raise TypeError
 
-        if type and not reference:
-            query = query.filter(Citation.type.like(type))
-        elif reference and type:
-            query = query.filter(Citation.reference == reference)
-        elif reference and not type:
+        if db and not db_id:
+            query = query.filter(Citation.db.like(db))
+        elif db_id and db:
+            query = query.filter(Citation.db_id == db_id)
+        elif db_id and not db:
             raise ValueError('reference specified without type')
 
         if name:
@@ -221,7 +223,7 @@ class QueryManager(LookupManager):
 
     def query_edges_by_pubmed_identifiers(self, pubmed_identifiers: List[str]) -> List[Edge]:
         """Get all edges annotated to the documents identified by the given PubMed identifiers."""
-        fi = and_(Citation.type == CITATION_TYPE_PUBMED, Citation.reference.in_(pubmed_identifiers))
+        fi = and_(Citation.db == CITATION_TYPE_PUBMED, Citation.db_id.in_(pubmed_identifiers))
         return self.session.query(Edge).join(Evidence).join(Citation).filter(fi).all()
 
     @staticmethod
