@@ -6,12 +6,12 @@ import logging
 import time
 from typing import Iterable, List
 
-from pyparsing import ParseResults
-
-log = logging.getLogger(__name__)
+from pyparsing import ParseResults, ParserElement
 
 __all__ = ['BaseParser']
 
+logger = logging.getLogger(__name__)
+
 
 class BaseParser(object):
     """This abstract class represents a language backed by a PyParsing statement.
@@ -19,11 +19,11 @@ class BaseParser(object):
     Multiple parsers can be easily chained together when they are all inheriting from this base class.
     """
 
-    def __init__(self, language, streamline=False):
+    def __init__(self, language: ParserElement, streamline: bool = False) -> None:
         """Build a parser wrapper using a PyParsing language.
 
         :param language: The PyParsing language to use
-        :param bool streamline: Should the language be streamlined on instantiation?
+        :param streamline: Should the language be streamlined on instantiation?
         """
         self.language = language
 
@@ -53,8 +53,8 @@ class BaseParser(object):
         """Get the current line number."""
         return self._line_number
 
-    def streamline(self):
+    def streamline(self) -> None:
         """Streamline the language represented by this parser to make queries run faster."""
         t = time.time()
         self.language.streamline()
-        log.info('streamlined %s in %.02f seconds', self.__class__.__name__, time.time() - t)
+        logger.info('streamlined %s in %.02f seconds', self.__class__.__name__, time.time() - t)
