@@ -8,7 +8,9 @@ automatically translated to the appropriate HGVS :code:`g(HGNC:APP, var(c.275341
 substitutions are using the reference coding gene sequence for numbering and not the genomic reference.
 The previous statements both produce the underlying data:
 
-.. code::
+.. code-block:: python
+
+    from pybel.constants import *
 
     {
         FUNCTION: GENE,
@@ -17,9 +19,9 @@ The previous statements both produce the underlying data:
         VARIANTS: [
             {
                 KIND: HGVS,
-                IDENTIFIER: 'c.275341G>C'
-            }
-        ]
+                IDENTIFIER: 'c.275341G>C',
+            },
+        ],
     }
 
 .. seealso::
@@ -30,40 +32,37 @@ The previous statements both produce the underlying data:
 
 import logging
 
-from pyparsing import oneOf, pyparsing_common as ppc
+from pyparsing import ParserElement, oneOf, pyparsing_common as ppc
 
 from ..utils import nest, one_of_tags
 from ... import language
-from ...constants import GSUB_POSITION, GSUB_REFERENCE, GSUB_VARIANT, HGVS, IDENTIFIER, KIND
+from ...constants import GSUB_POSITION, GSUB_REFERENCE, GSUB_VARIANT, HGVS, KIND
 
 __all__ = [
     'get_gene_substitution_language',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 dna_nucleotide = oneOf(list(language.dna_nucleotide_labels.keys()))
 gsub_tag = one_of_tags(tags=['sub', 'substitution'], canonical_tag=HGVS, name=KIND)
 
 
-def get_gene_substitution_language():
-    """Build a gene substitution parser.
-
-    :rtype: pyparsing.ParseElement
-    """
-    language = gsub_tag + nest(
+def get_gene_substitution_language() -> ParserElement:
+    """Build a gene substitution parser."""
+    parser_element = gsub_tag + nest(
         dna_nucleotide(GSUB_REFERENCE),
         ppc.integer(GSUB_POSITION),
         dna_nucleotide(GSUB_VARIANT),
     )
-    language.setParseAction(_handle_gsub)
-    return language
+    parser_element.setParseAction(_handle_gsub)
+    return parser_element
 
 
 def _handle_gsub(line, _, tokens):
     upgraded = 'c.{}{}>{}'.format(tokens[GSUB_POSITION], tokens[GSUB_REFERENCE], tokens[GSUB_VARIANT])
-    log.debug('legacy sub() %s upgraded to %s', line, upgraded)
-    tokens[IDENTIFIER] = upgraded
+    logger.debug('legacy sub() %s upgraded to %s', line, upgraded)
+    tokens[HGVS] = upgraded
     del tokens[GSUB_POSITION]
     del tokens[GSUB_REFERENCE]
     del tokens[GSUB_VARIANT]
