@@ -3,15 +3,17 @@
 """Locations.
 
 Location data also is added into the information in the edge for the node (subject or object) for which it was
-annotated. :code:`p(HGNC:GSK3B, pmod(P, S, 9), loc(GOCC:lysozome)) pos act(p(HGNC:GSK3B), ma(kin))` becomes:
+annotated. :code:`p(HGNC:GSK3B, pmod(P, S, 9), loc(GO:lysozome)) pos act(p(HGNC:GSK3B), ma(kin))` becomes:
 
-.. code::
+.. code-block:: python
+
+    from pybel.constants import *
 
     {
         SUBJECT: {
             LOCATION: {
-                NAMESPACE: 'GOCC',
-                NAME: 'lysozome'
+                NAMESPACE: 'GO',
+                NAME: 'lysozome',
             }
         },
         RELATION: POSITIVE_CORRELATION,
@@ -22,8 +24,8 @@ annotated. :code:`p(HGNC:GSK3B, pmod(P, S, 9), loc(GOCC:lysozome)) pos act(p(HGN
                 NAME: 'kin',
             }
         },
-        EVIDENCE: '...',
-        CITATION: { ... }
+        EVIDENCE: ...,
+        CITATION: { ... },
     }
 
 
@@ -33,8 +35,8 @@ hypothetical :code:`HGNC:A` in a specific location having different effects. In
 but this introduced unnecessary complexity to the network and made querying more difficult.
 This calls for thoughtful consideration of the following two statements:
 
-- :code:`tloc(p(HGNC:A), fromLoc(GOCC:intracellular), toLoc(GOCC:"cell membrane")) -> p(HGNC:B)`
-- :code:`p(HGNC:A, location(GOCC:"cell membrane")) -> p(HGNC:B)`
+- :code:`tloc(p(HGNC:A), fromLoc(GO:intracellular), toLoc(GO:"cell membrane")) -> p(HGNC:B)`
+- :code:`p(HGNC:A, location(GO:"cell membrane")) -> p(HGNC:B)`
 
 .. seealso::
 
@@ -42,7 +44,7 @@ This calls for thoughtful consideration of the following two statements:
     - PyBEL module :py:class:`pybel.parser.modifiers.get_location_language`
 """
 
-from pyparsing import Group, Suppress, oneOf
+from pyparsing import Group, ParserElement, Suppress, oneOf
 
 from ..utils import nest
 from ...constants import LOCATION
@@ -54,12 +56,6 @@ __all__ = [
 location_tag = Suppress(oneOf(['loc', 'location']))
 
 
-def get_location_language(identifier):
-    """Build a location parser.
-
-    :rtype: pyparsing.ParseElement
-    """
-    return Group(
-        location_tag +
-        nest(identifier)
-    )(LOCATION)
+def get_location_language(identifier: ParserElement) -> ParserElement:
+    """Build a location parser."""
+    return Group(location_tag + nest(identifier))(LOCATION)
