@@ -12,25 +12,26 @@ optionally include the position ('pos') and/or amino acid code ('code').
 
 For example, the node :code:`p(HGNC:GSK3B, pmod(P, S, 9))` is represented with the following:
 
-.. code::
+.. code-block:: python
 
-   {
-       FUNCTION: PROTEIN,
-       NAMESPACE: 'HGNC',
-       NAME: 'GSK3B',
-       VARIANTS: [
-           {
-               KIND: PMOD,
-               IDENTIFIER: {
-                   NAMESPACE: BEL_DEFAULT_NAMESPACE
-                   NAME: 'Ph',
+    from pybel.constants import *
 
-               },
-               PMOD_CODE: 'Ser',
-               PMOD_POSITION: 9
-           }
-       ]
-   }
+    {
+        FUNCTION: PROTEIN,
+        NAMESPACE: 'HGNC',
+        NAME: 'GSK3B',
+        VARIANTS: [
+            {
+                KIND: PMOD,
+                IDENTIFIER: {
+                    NAMESPACE: BEL_DEFAULT_NAMESPACE
+                    NAME: 'Ph',
+                },
+                PMOD_CODE: 'Ser',
+                PMOD_POSITION: 9,
+            },
+        ],
+    }
 
 
 As an additional example, in :code:`p(HGNC:MAPK1, pmod(Ph, Thr, 202), pmod(Ph, Tyr, 204))`, MAPK is phosphorylated
@@ -79,25 +80,25 @@ from pyparsing import Group, MatchFirst, Optional, ParseResults, ParserElement,
 
 from .constants import amino_acid
 from ..utils import WCW, nest, one_of_tags
-from ...constants import BEL_DEFAULT_NAMESPACE, IDENTIFIER, KIND, NAME, NAMESPACE, PMOD, PMOD_CODE, PMOD_POSITION
+from ...constants import BEL_DEFAULT_NAMESPACE, CONCEPT, KIND, NAME, NAMESPACE, PMOD, PMOD_CODE, PMOD_POSITION
 from ...language import pmod_legacy_labels, pmod_namespace
 
 __all__ = [
     'get_protein_modification_language',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 def _handle_pmod_default_ns(_, __, tokens: ParseResults) -> ParseResults:
     tokens[NAMESPACE] = BEL_DEFAULT_NAMESPACE
-    tokens['name'] = pmod_namespace[tokens[0]]
+    tokens[NAME] = pmod_namespace[tokens[0]]
     return tokens
 
 
 def _handle_pmod_legacy_ns(line, _, tokens: ParseResults) -> ParseResults:
     upgraded = pmod_legacy_labels[tokens[0]]
-    log.log(5, 'legacy pmod() value %s upgraded to %s', line, upgraded)
+    logger.log(5, 'legacy pmod() value %s upgraded to %s', line, upgraded)
     tokens[NAMESPACE] = BEL_DEFAULT_NAMESPACE
     tokens[NAME] = upgraded
     return tokens
@@ -108,22 +109,19 @@ pmod_default_ns = oneOf(list(pmod_namespace)).setParseAction(_handle_pmod_defaul
 pmod_legacy_ns = oneOf(list(pmod_legacy_labels)).setParseAction(_handle_pmod_legacy_ns)
 
 
-def get_protein_modification_language(identifier_qualified: ParserElement) -> ParserElement:
-    """Build a protein modificaiton parser."""
-    pmod_identifier = MatchFirst([
-        identifier_qualified,
+def get_protein_modification_language(concept_qualified: ParserElement) -> ParserElement:
+    """Build a protein modification parser."""
+    pmod_concept = MatchFirst([
+        concept_qualified,
         pmod_default_ns,
-        pmod_legacy_ns
+        pmod_legacy_ns,
     ])
 
     return pmod_tag + nest(
-        Group(pmod_identifier)(IDENTIFIER) +
-        Optional(
-            WCW +
-            amino_acid(PMOD_CODE) +
-            Optional(
-                WCW +
-                ppc.integer(PMOD_POSITION)
-            )
-        )
+        Group(pmod_concept)(CONCEPT)
+        + Optional(
+            WCW
+            + amino_acid(PMOD_CODE)
+            + Optional(WCW + ppc.integer(PMOD_POSITION)),
+        ),
     )
