@@ -8,7 +8,9 @@ automatically translated to the appropriate HGVS :code:`p(HGNC:APP, var(p.Arg275
 substitutions are using the reference protein sequence for numbering and not the genomic reference.
 The previous statements both produce the underlying data:
 
-.. code::
+.. code-block:: python
+
+    from pybel.constants import *
 
     {
         FUNCTION: GENE,
@@ -17,9 +19,9 @@ The previous statements both produce the underlying data:
         VARIANTS: [
             {
                 KIND: HGVS,
-                IDENTIFIER: 'p.Arg275His'
-            }
-        ]
+                IDENTIFIER: 'p.Arg275His',
+            },
+        ],
     }
 
 .. seealso::
@@ -31,41 +33,36 @@ The previous statements both produce the underlying data:
 
 import logging
 
-from pyparsing import pyparsing_common as ppc
+from pyparsing import ParserElement, pyparsing_common as ppc
 
 from .constants import amino_acid
 from ..utils import nest, one_of_tags
-from ...constants import (
-    HGVS, IDENTIFIER, KIND, PSUB_POSITION, PSUB_REFERENCE, PSUB_VARIANT,
-)
+from ...constants import HGVS, KIND, PSUB_POSITION, PSUB_REFERENCE, PSUB_VARIANT
 
 __all__ = [
     'get_protein_substitution_language',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 psub_tag = one_of_tags(tags=['sub', 'substitution'], canonical_tag=HGVS, name=KIND)
 
 
-def get_protein_substitution_language():
-    """Build a protein substitution parser.
-
-    :rtype: pyparsing.ParseElement
-    """
-    language = psub_tag + nest(
+def get_protein_substitution_language() -> ParserElement:
+    """Build a protein substitution parser."""
+    parser_element = psub_tag + nest(
         amino_acid(PSUB_REFERENCE),
         ppc.integer(PSUB_POSITION),
         amino_acid(PSUB_VARIANT),
     )
-    language.setParseAction(_handle_psub)
-    return language
+    parser_element.setParseAction(_handle_psub)
+    return parser_element
 
 
 def _handle_psub(line, _, tokens):
     upgraded = 'p.{}{}{}'.format(tokens[PSUB_REFERENCE], tokens[PSUB_POSITION], tokens[PSUB_VARIANT])
-    log.log(5, 'sub() in p() is deprecated: %s. Upgraded to %s', line, upgraded)
-    tokens[IDENTIFIER] = upgraded
+    logger.log(5, 'sub() in p() is deprecated: %s. Upgraded to %s', line, upgraded)
+    tokens[HGVS] = upgraded
     del tokens[PSUB_REFERENCE]
     del tokens[PSUB_POSITION]
     del tokens[PSUB_VARIANT]
