@@ -6,7 +6,9 @@ Truncations in the legacy BEL 1.0 specification are automatically translated to
 :code:`p(HGNC:AKT1, trunc(40))` becomes :code:`p(HGNC:AKT1, var(p.40*))` and is represented with the following
 dictionary:
 
-.. code::
+.. code-block:: python
+
+    from pybel.constants import *
 
     {
         FUNCTION: PROTEIN,
@@ -15,9 +17,9 @@ dictionary:
         VARIANTS: [
             {
                 KIND: HGVS,
-                IDENTIFIER: 'p.40*'
-            }
-        ]
+                IDENTIFIER: 'p.40*',
+            },
+        ],
     }
 
 Unfortunately, the HGVS nomenclature requires the encoding of the terminal amino acid which is exchanged
@@ -35,28 +37,25 @@ looking up the amino acid sequence.
 
 import logging
 
-from pyparsing import pyparsing_common as ppc
+from pyparsing import ParserElement, pyparsing_common as ppc
 
 from .constants import amino_acid
 from ..utils import nest, one_of_tags
-from ...constants import HGVS, IDENTIFIER, KIND, TRUNCATION_POSITION
+from ...constants import HGVS, KIND, TRUNCATION_POSITION
 
 __all__ = [
     'get_truncation_language',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 truncation_tag = one_of_tags(tags=['trunc', 'truncation'], canonical_tag=HGVS, name=KIND)
 
 AMINO_ACID = 'aminoacid'
 
 
-def get_truncation_language():
-    """Build a parser for protein truncations.
-
-    :rtype: pyparsing.ParseElement
-    """
+def get_truncation_language() -> ParserElement:
+    """Build a parser for protein truncations."""
     l1 = truncation_tag + nest(amino_acid(AMINO_ACID) + ppc.integer(TRUNCATION_POSITION))
     l1.setParseAction(_handle_trunc)
     l2 = truncation_tag + nest(ppc.integer(TRUNCATION_POSITION))
@@ -67,15 +66,15 @@ def get_truncation_language():
 def _handle_trunc_legacy(line, _, tokens):
     # FIXME this isn't correct HGVS nomenclature, but truncation isn't forward compatible without more information
     upgraded = 'p.{}*'.format(tokens[TRUNCATION_POSITION])
-    log.warning('trunc() is deprecated. Re-encode with reference terminal amino acid in HGVS: %s', line)
-    tokens[IDENTIFIER] = upgraded
+    logger.warning('trunc() is deprecated. Re-encode with reference terminal amino acid in HGVS: %s', line)
+    tokens[HGVS] = upgraded
     del tokens[TRUNCATION_POSITION]
     return tokens
 
 
 def _handle_trunc(_, __, tokens):
     aa, position = tokens[AMINO_ACID], tokens[TRUNCATION_POSITION]
-    tokens[IDENTIFIER] = 'p.{aa}{position}*'.format(aa=aa, position=position)
+    tokens[HGVS] = 'p.{aa}{position}*'.format(aa=aa, position=position)
     del tokens[AMINO_ACID]
     del tokens[TRUNCATION_POSITION]
     return tokens
