@@ -9,6 +9,7 @@ from typing import Mapping, Optional, Pattern, Set
 from pyparsing import And, MatchFirst, ParseResults, Suppress, Word, pyparsing_common as ppc
 
 from .baseparser import BaseParser
+from .constants import NamespaceTermEncodingMapping
 from .exc import InvalidMetadataException, RedefinedAnnotationError, RedefinedNamespaceError, VersionFormatWarning
 from .utils import delimited_quoted_list, qid, quote, word
 from ..constants import (
@@ -16,11 +17,14 @@ from ..constants import (
     BEL_KEYWORD_NAMESPACE, BEL_KEYWORD_PATTERN, BEL_KEYWORD_SET, BEL_KEYWORD_URL, DOCUMENT_KEYS, METADATA_VERSION,
     belns_encodings,
 )
+from ..resources.resources import keyword_to_url
 from ..utils import valid_date_version
 
-__all__ = ['MetadataParser']
+__all__ = [
+    'MetadataParser',
+]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 as_tag = Suppress(BEL_KEYWORD_AS)
 url_tag = Suppress(BEL_KEYWORD_URL)
@@ -31,10 +35,13 @@ define_tag = Suppress(BEL_KEYWORD_DEFINE)
 function_tags = Word(''.join(belns_encodings))
 
 SEMANTIC_VERSION_STRING_RE = re.compile(
-    r'(?P<major>\d+)\.(?P<minor>\d+)\.(?P<patch>\d+)(?:-(?P<release>[0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?(?:\+(?P<build>[0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?')
+    r'(?P<major>\d+)\.(?P<minor>\d+)\.(?P<patch>\d+)(?:-(?P<release>[0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?(?:\+(?P<build>[0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?',
+)
 
 MALFORMED_VERSION_STRING_RE = re.compile(r'(?P<major>\d+)(\.(?P<minor>\d+)(\.(?P<patch>\d+))?)?')
 
+NAMESPACE_BLACKLIST = {}  # TODO: {'SCOMP', 'SFAM'}
+
 
 class MetadataParser(BaseParser):
     """A parser for the document and definitions section of a BEL document.
@@ -44,22 +51,26 @@ class MetadataParser(BaseParser):
         BEL 1.0 Specification for the `DEFINE <http://openbel.org/language/web/version_1.0/bel_specification_version_1.0.html#_define>`_ keyword
     """
 
-    def __init__(self,
-                 manager,
-                 namespace_to_term: Optional[Mapping[str, Mapping[str, str]]] = None,
-                 namespace_to_pattern: Optional[Mapping[str, Pattern]] = None,
-                 annotation_to_term: Optional[Mapping[str, Set[str]]] = None,
-                 annotation_to_pattern: Optional[Mapping[str, Pattern]] = None,
-                 annotation_to_local: Optional[Mapping[str, Set[str]]] = None,
-                 default_namespace: Optional[Set[str]] = None,
-                 allow_redefinition: bool = False,
-                 skip_validation: bool = False,
-                 ) -> None:
+    def __init__(
+        self,
+        manager,
+        namespace_to_term_to_encoding: Optional[NamespaceTermEncodingMapping] = None,
+        namespace_to_pattern: Optional[Mapping[str, Pattern]] = None,
+        annotation_to_term: Optional[Mapping[str, Set[str]]] = None,
+        annotation_to_pattern: Optional[Mapping[str, Pattern]] = None,
+        annotation_to_local: Optional[Mapping[str, Set[str]]] = None,
+        default_namespace: Optional[Set[str]] = None,
+        allow_redefinition: bool = False,
+        skip_validation: bool = False,
+        upgrade_urls: bool = False,
+    ) -> None:
         """Build a metadata parser.
 
         :param manager: A cache manager
-        :param namespace_to_term: Enumerated namespace mapping from {namespace keyword: {name: encoding}}
-        :param namespace_to_pattern: Regular expression namespace mapping from {namespace keyword: regex string}
+        :param namespace_to_term_to_encoding:
+          An enumerated namespace mapping from {namespace keyword: {(identifier, name): encoding}}
+        :param namespace_to_pattern:
+          A regular expression namespace mapping from {namespace keyword: regex string}
         :param annotation_to_term: Enumerated annotation mapping from {annotation keyword: set of valid values}
         :param annotation_to_pattern: Regular expression annotation mapping from {annotation keyword: regex string}
         :param default_namespace: A set of strings that can be used without a namespace
@@ -69,9 +80,10 @@ class MetadataParser(BaseParser):
         self.manager = manager
         self.disallow_redefinition = not allow_redefinition
         self.skip_validation = skip_validation
+        self.upgrade_urls = upgrade_urls
 
-        #: A dictionary of cached {namespace keyword: {name: encoding}}
-        self.namespace_to_term = namespace_to_term or {}
+        #: A dictionary of cached {namespace keyword: {(identifier, name): encoding}}
+        self.namespace_to_term_to_encoding = namespace_to_term_to_encoding or {}
         #: A set of namespaces's URLs that can't be cached
         self.uncachable_namespaces = set()
         #: A dictionary of {namespace keyword: regular expression string}
@@ -99,7 +111,7 @@ class MetadataParser(BaseParser):
             Suppress(BEL_KEYWORD_DOCUMENT),
             word('key'),
             Suppress('='),
-            qid('value')
+            qid('value'),
         ])
 
         namespace_tag = And([define_tag, Suppress(BEL_KEYWORD_NAMESPACE), ppc.identifier('name'), as_tag])
@@ -124,12 +136,12 @@ class MetadataParser(BaseParser):
             self.annotation_url,
             self.annotation_list,
             self.annotation_pattern,
-            self.namespace_pattern
+            self.namespace_pattern,
         ]).setName('BEL Metadata')
 
         super(MetadataParser, self).__init__(self.language)
 
-    def handle_document(self, line: str, position: int, tokens: ParseResults)-> ParseResults:
+    def handle_document(self, line: str, position: int, tokens: ParseResults) -> ParseResults:
         """Handle statements like ``SET DOCUMENT X = "Y"``.
 
         :raises: InvalidMetadataException
@@ -144,7 +156,7 @@ class MetadataParser(BaseParser):
         norm_key = DOCUMENT_KEYS[key]
 
         if norm_key in self.document_metadata:
-            log.warning('Tried to overwrite metadata: %s', key)
+            logger.warning('Tried to overwrite metadata: %s', key)
             return tokens
 
         self.document_metadata[norm_key] = value
@@ -162,28 +174,30 @@ class MetadataParser(BaseParser):
         if self.disallow_redefinition and self.has_namespace(namespace):
             raise RedefinedNamespaceError(self.get_line_number(), line, position, namespace)
 
-    def handle_namespace_url(self, line: str, position: int, tokens: ParseResults)-> ParseResults:
+    def handle_namespace_url(self, line: str, position: int, tokens: ParseResults) -> ParseResults:
         """Handle statements like ``DEFINE NAMESPACE X AS URL "Y"``.
 
         :raises: RedefinedNamespaceError
         :raises: pybel.resources.exc.ResourceError
         """
-        namespace = tokens['name']
-        self.raise_for_redefined_namespace(line, position, namespace)
+        namespace_keyword = tokens['name']
+
+        if namespace_keyword in NAMESPACE_BLACKLIST:
+            raise ValueError('Upgrade usage to FamPlex')
+
+        self.raise_for_redefined_namespace(line, position, namespace_keyword)
 
         url = tokens['url']
-        self.namespace_url_dict[namespace] = url
+        if self.upgrade_urls and namespace_keyword.lower() in keyword_to_url:
+            url = keyword_to_url[namespace_keyword.lower()]
+
+        self.namespace_url_dict[namespace_keyword] = url
 
         if self.skip_validation:
             return tokens
 
-        namespace_result = self.manager.get_or_create_namespace(url)
-
-        if isinstance(namespace_result, dict):
-            self.namespace_to_term[namespace] = namespace_result
-            self.uncachable_namespaces.add(url)
-        else:
-            self.namespace_to_term[namespace] = self.manager.get_namespace_encoding(url)
+        namespace = self.manager.get_or_create_namespace(url)
+        self.namespace_to_term_to_encoding[namespace_keyword] = namespace.get_term_to_encodings()
 
         return tokens
 
@@ -205,7 +219,7 @@ class MetadataParser(BaseParser):
         if self.disallow_redefinition and self.has_annotation(annotation):
             raise RedefinedAnnotationError(self.get_line_number(), line, position, annotation)
 
-    def handle_annotations_url(self, line: str, position: int, tokens: ParseResults)-> ParseResults:
+    def handle_annotations_url(self, line: str, position: int, tokens: ParseResults) -> ParseResults:
         """Handle statements like ``DEFINE ANNOTATION X AS URL "Y"``.
 
         :raises: RedefinedAnnotationError
@@ -258,14 +272,14 @@ class MetadataParser(BaseParser):
     def has_annotation(self, annotation: str) -> bool:
         """Check if this annotation is defined."""
         return (
-            self.has_enumerated_annotation(annotation) or
-            self.has_regex_annotation(annotation) or
-            self.has_local_annotation(annotation)
+            self.has_enumerated_annotation(annotation)
+            or self.has_regex_annotation(annotation)
+            or self.has_local_annotation(annotation)
         )
 
     def has_enumerated_namespace(self, namespace: str) -> bool:
         """Check if this namespace is defined by an enumeration."""
-        return namespace in self.namespace_to_term
+        return namespace in self.namespace_to_term_to_encoding
 
     def has_regex_namespace(self, namespace: str) -> bool:
         """Check if this namespace is defined by a regular expression."""
