@@ -7,8 +7,8 @@ and the concept of `predicates <https://en.wikipedia.org/wiki/Predicate_(mathema
 """
 
 from . import (
-    edge_filters, edge_predicate_builders, edge_predicates, node_filters,
-    node_predicate_builders, node_predicates, utils,
+    edge_filters, edge_predicate_builders, edge_predicates, node_filters, node_predicate_builders, node_predicates,
+    typing, utils,
 )
 from .edge_filters import *
 from .edge_predicate_builders import *
@@ -16,4 +16,7 @@ from .edge_predicates import *
 from .node_filters import *
 from .node_predicate_builders import *
 from .node_predicates import *
+from .typing import *
 from .utils import *
+
+__all__ = [k for k in locals() if not k.startswith('_')]
