@@ -2,13 +2,16 @@
 
 """This module contains functions that mutate or make transformations on a network."""
 
-from . import collapse, deletion, expansion, induction, induction_expansion, inference, metadata, transfer, utils
+from pybel.struct.mutation.inference.transfer import *
+from . import collapse, deletion, expansion, induction, induction_expansion, inference, metadata, utils
 from .collapse import *
 from .deletion import *
 from .expansion import *
 from .induction import *
 from .induction_expansion import *
 from .inference import *
+from .inference import transfer
 from .metadata import *
-from .transfer import *
 from .utils import *
+
+__all__ = [k for k in locals() if not k.startswith('_')]
