@@ -3,7 +3,7 @@
 """Functions for expanding a graph based on the upstream/downstream edges."""
 
 from ..utils import expand_by_edge_filter
-from ...filters import build_downstream_edge_predicate, build_upstream_edge_predicate
+from ...filters.edge_predicate_builders import build_downstream_edge_predicate, build_upstream_edge_predicate
 from ...pipeline import uni_in_place_transformation
 
 __all__ = [
