@@ -7,8 +7,4 @@ from .decorators import *
 from .exc import *
 from .pipeline import *
 
-__all__ = (
-    decorators.__all__
-    + exc.__all__
-    + pipeline.__all__
-)
+__all__ = [k for k in locals() if not k.startswith('_')]
