@@ -9,54 +9,54 @@ A transformation function takes in a :class:`pybel.BELGraph` and either returns
 import logging
 from inspect import signature
 
-from .exc import DeprecationMappingError, MissingPipelineFunctionError, PipelineNameError
+from .exc import MissingPipelineFunctionError, PipelineNameError
 
 __all__ = [
     'in_place_transformation',
     'uni_in_place_transformation',
     'uni_transformation',
     'transformation',
-    'register_deprecated',
     'get_transformation',
     'mapped',
     'has_arguments_map',
     'no_arguments_map',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 mapped = {}
 universe_map = {}
 in_place_map = {}
 has_arguments_map = {}
 no_arguments_map = {}
-deprecated = {}
 
 
 def _has_arguments(func, universe):
     sig = signature(func)
     return (
-        (universe and 3 <= len(sig.parameters)) or
-        (not universe and 2 <= len(sig.parameters))
+        (universe and 3 <= len(sig.parameters))
+        or (not universe and 2 <= len(sig.parameters))
     )
 
 
-def _register_function(name, func, universe, in_place):
+def _register_function(name: str, func, universe: bool, in_place: bool):
     """Register a transformation function under the given name.
 
-    :param str name: Name to register the function under
+    :param name: Name to register the function under
     :param func: A function
-    :param bool universe:
-    param bool in_place:
+    :param universe:
+    :param in_place:
     :return: The same function, with additional properties added
     """
     if name in mapped:
         mapped_func = mapped[name]
-        raise PipelineNameError('{name} is already registered with {func_mod}.{func_name}'.format(
-            name=name,
-            func_mod=mapped_func.__module__,
-            func_name=mapped_func.__name__
-        ))
+        raise PipelineNameError(
+            '{name} is already registered with {func_mod}.{func_name}'.format(
+                name=name,
+                func_mod=mapped_func.__module__,
+                func_name=mapped_func.__name__,
+            ),
+        )
 
     mapped[name] = func
 
@@ -74,11 +74,11 @@ def _register_function(name, func, universe, in_place):
     return func
 
 
-def _build_register_function(universe, in_place):  # noqa: D202
+def _build_register_function(universe: bool, in_place: bool):  # noqa: D202
     """Build a decorator function to tag transformation functions.
 
-    :param bool universe: Does the first positional argument of this function correspond to a universe graph?
-    :param bool in_place: Does this function return a new graph, or just modify it in-place?
+    :param universe: Does the first positional argument of this function correspond to a universe graph?
+    :param in_place: Does this function return a new graph, or just modify it in-place?
     """
 
     def register(func):
@@ -102,47 +102,10 @@ uni_transformation = _build_register_function(universe=True, in_place=False)
 transformation = _build_register_function(universe=False, in_place=False)
 
 
-def register_deprecated(deprecated_name):
-    """Register a function as deprecated.
-
-    :param str deprecated_name: The old name of the function
-    :return: A decorator
-
-    Usage:
-
-    This function must be applied last, since it introspects on the definitions from before
-
-    >>> @register_deprecated('my_function')
-    >>> @transformation
-    >>> def my_old_function()
-    >>> ... pass
-    """
-    if deprecated_name in mapped:
-        raise DeprecationMappingError('function name already mapped. can not register as deprecated name.')
-
-    def register_deprecated_f(func):
-        name = func.__name__
-
-        log.debug('%s is deprecated. please migrate to %s', deprecated_name, name)
-
-        if name not in mapped:
-            raise MissingPipelineFunctionError('function not mapped with transformation, uni_transformation, etc.')
-
-        universe = name in universe_map
-        in_place = name in in_place_map
-
-        # Add back-reference from deprecated function name to actual function name
-        deprecated[deprecated_name] = name
-
-        return _register_function(deprecated_name, func, universe, in_place)
-
-    return register_deprecated_f
-
-
-def get_transformation(name):
+def get_transformation(name: str):
     """Get a transformation function and error if its name is not registered.
 
-    :param str name: The name of a function to look up
+    :param name: The name of a function to look up
     :return: A transformation function
     :raises MissingPipelineFunctionError: If the given function name is not registered
     """
