@@ -3,6 +3,7 @@
 """A wrapper around selection methods."""
 
 import logging
+from typing import Any, List, Optional
 
 from .constants import (
     SEED_TYPE_ANNOTATION, SEED_TYPE_AUTHOR, SEED_TYPE_DOUBLE_NEIGHBORS, SEED_TYPE_DOWNSTREAM,
@@ -13,15 +14,22 @@ from ..mutation import (
     get_random_subgraph, get_subgraph_by_all_shortest_paths, get_subgraph_by_annotations, get_subgraph_by_authors,
     get_subgraph_by_induction, get_subgraph_by_neighborhood, get_subgraph_by_pubmed, get_subgraph_by_second_neighbors,
 )
-
-log = logging.getLogger(__name__)
+from ...dsl import BaseEntity
 
 __all__ = [
     'get_subgraph',
 ]
 
+logger = logging.getLogger(__name__)
 
-def get_subgraph(graph, seed_method=None, seed_data=None, expand_nodes=None, remove_nodes=None):
+
+def get_subgraph(
+    graph,
+    seed_method: Optional[str] = None,
+    seed_data: Optional[Any] = None,
+    expand_nodes: Optional[List[BaseEntity]] = None,
+    remove_nodes: Optional[List[BaseEntity]] = None,
+):
     """Run a pipeline query on graph with multiple sub-graph filters and expanders.
 
     Order of Operations:
@@ -31,10 +39,10 @@ def get_subgraph(graph, seed_method=None, seed_data=None, expand_nodes=None, rem
     3. Remove nodes
 
     :param pybel.BELGraph graph: A BEL graph
-    :param str seed_method: The name of the get_subgraph_by_* function to use
+    :param seed_method: The name of the get_subgraph_by_* function to use
     :param seed_data: The argument to pass to the get_subgraph function
-    :param list[tuple] expand_nodes: Add the neighborhoods around all of these nodes
-    :param list[tuple] remove_nodes: Remove these nodes and all of their in/out edges
+    :param expand_nodes: Add the neighborhoods around all of these nodes
+    :param remove_nodes: Remove these nodes and all of their in/out edges
     :rtype: Optional[pybel.BELGraph]
     """
     # Seed by the given function
@@ -69,42 +77,42 @@ def get_subgraph(graph, seed_method=None, seed_data=None, expand_nodes=None, rem
         result = get_random_subgraph(
             graph,
             number_edges=seed_data.get('number_edges'),
-            seed=seed_data.get('seed')
+            seed=seed_data.get('seed'),
         )
 
     elif not seed_method:  # Otherwise, don't seed a sub-graph
         result = graph.copy()
-        log.debug('no seed function - using full network: %s', result.name)
+        logger.debug('no seed function - using full network: %s', result.name)
 
     else:
         raise ValueError('Invalid seed method: {}'.format(seed_method))
 
     if result is None:
-        log.debug('query returned no results')
+        logger.debug('query returned no results')
         return
 
-    log.debug('original graph has (%s nodes / %s edges)', result.number_of_nodes(), result.number_of_edges())
+    logger.debug('original graph has (%s nodes / %s edges)', result.number_of_nodes(), result.number_of_edges())
 
     # Expand around the given nodes
     if expand_nodes:
         expand_nodes_neighborhoods(graph, result, expand_nodes)
-        log.debug('graph expanded to (%s nodes / %s edges)', result.number_of_nodes(), result.number_of_edges())
+        logger.debug('graph expanded to (%s nodes / %s edges)', result.number_of_nodes(), result.number_of_edges())
 
     # Delete the given nodes
     if remove_nodes:
         for node in remove_nodes:
             if node not in result:
-                log.debug('%s is not in graph %s', node, graph.name)
+                logger.debug('%s is not in graph %s', node, graph.name)
                 continue
             result.remove_node(node)
-        log.debug('graph contracted to (%s nodes / %s edges)', result.number_of_nodes(), result.number_of_edges())
+        logger.debug('graph contracted to (%s nodes / %s edges)', result.number_of_nodes(), result.number_of_edges())
 
-    log.debug(
+    logger.debug(
         'Subgraph coming from %s (seed type) %s (data) contains %d nodes and %d edges',
         seed_method,
         seed_data,
         result.number_of_nodes(),
-        result.number_of_edges()
+        result.number_of_edges(),
     )
 
     return result
