@@ -8,9 +8,4 @@ from .errors import *
 from .node_summary import *
 from .provenance import *
 
-__all__ = (
-    errors.__all__
-    + node_summary.__all__
-    + provenance.__all__
-    + edge_summary.__all__
-)
+__all__ = [k for k in locals() if not k.startswith('_')]
