@@ -5,26 +5,28 @@
 import hashlib
 import json
 import logging
+import pickle
 from collections import defaultdict
 from collections.abc import Iterable, MutableMapping
 from datetime import datetime
-from pickle import dumps
-from typing import Mapping, Optional, Tuple
+from typing import Any, Mapping, Optional, Tuple
 
 from .constants import (
-    ACTIVITY, CITATION, CITATION_REFERENCE, CITATION_TYPE, DEGRADATION, EFFECT, EVIDENCE, FROM_LOC, IDENTIFIER,
-    LOCATION, MODIFIER, NAME, NAMESPACE, OBJECT, RELATION, SUBJECT, TO_LOC, TRANSLOCATION, VERSION,
+    ACTIVITY, CITATION, CITATION_DB, CITATION_DB_NAME, CITATION_IDENTIFIER, DEGRADATION, EFFECT, EVIDENCE, FROM_LOC,
+    IDENTIFIER, LOCATION, MODIFIER, NAME, NAMESPACE, OBJECT, RELATION, SUBJECT, TO_LOC, TRANSLOCATION,
 )
 from .typing import EdgeData
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
+
+CanonicalEdge = Tuple[str, Optional[Tuple], Optional[Tuple]]
 
 
-def expand_dict(flat_dict, sep='_'):
+def expand_dict(flat_dict, sep: str = '_'):
     """Expand a flattened dictionary.
 
     :param dict flat_dict: a nested dictionary that has been flattened so the keys are composite
-    :param str sep: the separator between concatenated keys
+    :param sep: the separator between concatenated keys
     :rtype: dict
     """
     res = {}
@@ -43,13 +45,16 @@ def expand_dict(flat_dict, sep='_'):
     return res
 
 
-def flatten_dict(data, parent_key='', sep='_'):
+def flatten_dict(
+    data: Mapping[str, Any],
+    parent_key: str = '',
+    sep: str = '_',
+) -> Mapping[str, str]:
     """Flatten a nested dictionary.
 
     :param data: A nested dictionary
-    :type data: dict or MutableMapping
-    :param str parent_key: The parent's key. This is a value for tail recursion, so don't set it yourself.
-    :param str sep: The separator used between dictionary levels
+    :param parent_key: The parent's key. This is a value for tail recursion, so don't set it yourself.
+    :param sep: The separator used between dictionary levels
     :rtype: dict
 
     .. seealso:: http://stackoverflow.com/a/6027615
@@ -70,11 +75,6 @@ def flatten_dict(data, parent_key='', sep='_'):
     return items
 
 
-def get_version() -> str:
-    """Get the current PyBEL version."""
-    return VERSION
-
-
 def tokenize_version(version_string: str) -> Tuple[int, int, int]:
     """Tokenize a version string to a tuple.
 
@@ -115,9 +115,10 @@ def valid_date_version(s: str) -> bool:
 def _validate_date_fmt(s: str, fmt: str) -> bool:
     try:
         datetime.strptime(s, fmt)
-        return True
     except ValueError:
         return False
+    else:
+        return True
 
 
 def parse_datetime(s: str) -> datetime.date:
@@ -133,23 +134,31 @@ def parse_datetime(s: str) -> datetime.date:
     raise ValueError('Incorrect datetime format for {}'.format(s))
 
 
-def _hash_tuple(t):
-    return hashlib.sha512(dumps(t)).hexdigest()
-
-
 def _get_citation_str(data: Mapping) -> Optional[str]:
     citation = data.get(CITATION)
-
-    if citation is None:
-        return
-
-    return '{type}:{reference}'.format(type=citation[CITATION_TYPE], reference=citation[CITATION_REFERENCE])
+    if citation is not None:
+        return '{}:{}'.format(citation[CITATION_DB], citation[CITATION_IDENTIFIER])
 
 
-def _get_edge_tuple(source,
-                    target,
-                    edge_data: EdgeData,
-                    ) -> Tuple[str, str, str, Optional[str], Tuple[str, Optional[Tuple], Optional[Tuple]]]:
+def hash_edge(source, target, edge_data: EdgeData) -> str:
+    """Convert an edge tuple to a MD5 hash.
+
+    :param BaseEntity source: The source BEL node
+    :param BaseEntity target: The target BEL node
+    :param edge_data: The edge's data dictionary
+    :return: A hashed version of the edge tuple using MD5 hash of the binary pickle dump of u, v, and the json dump
+     of d
+    """
+    edge_tuple = _get_edge_tuple(source, target, edge_data)
+    edge_tuple_bytes = pickle.dumps(edge_tuple)
+    return hashlib.md5(edge_tuple_bytes).hexdigest()  # noqa: S303
+
+
+def _get_edge_tuple(
+    source,
+    target,
+    edge_data: EdgeData,
+) -> Tuple[str, str, Optional[str], Optional[str], CanonicalEdge]:
     """Convert an edge to a consistent tuple.
 
     :param BaseEntity source: The source BEL node
@@ -166,19 +175,7 @@ def _get_edge_tuple(source,
     )
 
 
-def hash_edge(source, target, edge_data: EdgeData) -> str:
-    """Convert an edge tuple to a SHA-512 hash.
-
-    :param BaseEntity source: The source BEL node
-    :param BaseEntity target: The target BEL node
-    :param edge_data: The edge's data dictionary
-    :return: A hashed version of the edge tuple using md5 hash of the binary pickle dump of u, v, and the json dump of d
-    """
-    edge_tuple = _get_edge_tuple(source, target, edge_data)
-    return _hash_tuple(edge_tuple)
-
-
-def subdict_matches(target, query, partial_match: bool = True) -> bool:
+def subdict_matches(target: Mapping, query: Mapping, partial_match: bool = True) -> bool:
     """Check if all the keys in the query dict are in the target dict, and that their values match.
 
     1. Checks that all keys in the query dict are in the target dict
@@ -187,8 +184,8 @@ def subdict_matches(target, query, partial_match: bool = True) -> bool:
         b. If the value is a set/list/tuple, then will match any of them
         c. If the value is a dict, then recursively check if that subdict matches
 
-    :param dict target: The dictionary to search
-    :param dict query: A query dict with keys to match
+    :param target: The dictionary to search
+    :param query: A query dict with keys to match
     :param partial_match: Should the query values be used as partial or exact matches? Defaults to :code:`True`.
     :return: if all keys in b are in target_dict and their values match
     """
@@ -219,31 +216,10 @@ def hash_dump(data) -> str:
     :param data: An arbitrary JSON-serializable object
     :type data: dict or list or tuple
     """
-    return hashlib.sha512(json.dumps(data, sort_keys=True).encode('utf-8')).hexdigest()
+    return hashlib.md5(json.dumps(data, sort_keys=True).encode('utf-8')).hexdigest()  # noqa: S303
 
 
-def hash_citation(type: str, reference: str) -> str:
-    """Create a hash for a type/reference pair of a citation.
-
-    :param type: The corresponding citation type
-    :param reference: The citation reference
-    """
-    s = u'{type}:{reference}'.format(type=type, reference=reference)
-    return hashlib.sha512(s.encode('utf8')).hexdigest()
-
-
-def hash_evidence(text: str, type: str, reference: str) -> str:
-    """Create a hash for an evidence and its citation.
-
-    :param text: The evidence text
-    :param type: The corresponding citation type
-    :param reference: The citation reference
-    """
-    s = u'{type}:{reference}:{text}'.format(type=type, reference=reference, text=text)
-    return hashlib.sha512(s.encode('utf8')).hexdigest()
-
-
-def canonicalize_edge(edge_data: EdgeData) -> Tuple[str, Optional[Tuple], Optional[Tuple]]:
+def canonicalize_edge(edge_data: EdgeData) -> CanonicalEdge:
     """Canonicalize the edge to a tuple based on the relation, subject modifications, and object modifications."""
     return (
         edge_data[RELATION],
@@ -268,18 +244,14 @@ def _canonicalize_edge_modifications(edge_data: EdgeData) -> Optional[Tuple]:
 
     if modifier == ACTIVITY:
         if effect:
-            effect_name = effect.get(NAME)
-            effect_identifier = effect.get(IDENTIFIER)
-
             t = (
                 ACTIVITY,
                 effect[NAMESPACE],
-                effect_name or effect_identifier,
+                effect.get(IDENTIFIER),
+                effect.get(NAME),
             )
-
         else:
             t = (ACTIVITY,)
-
         result.append(t)
 
     elif modifier == DEGRADATION:
@@ -288,30 +260,28 @@ def _canonicalize_edge_modifications(edge_data: EdgeData) -> Optional[Tuple]:
 
     elif modifier == TRANSLOCATION:
         if effect:
-            from_loc_name = effect[FROM_LOC].get(NAME)
-            from_loc_identifier = effect[FROM_LOC].get(IDENTIFIER)
-            to_loc_name = effect[TO_LOC].get(NAME)
-            to_loc_identifier = effect[TO_LOC].get(IDENTIFIER)
+            from_loc_concept = effect[FROM_LOC]
+            to_loc_concept = effect[TO_LOC]
 
             t = (
                 TRANSLOCATION,
-                edge_data[EFFECT][FROM_LOC][NAMESPACE],
-                from_loc_name or from_loc_identifier,
-                edge_data[EFFECT][TO_LOC][NAMESPACE],
-                to_loc_name or to_loc_identifier,
+                from_loc_concept[NAMESPACE],
+                from_loc_concept.get(IDENTIFIER),
+                from_loc_concept.get(NAME),
+                to_loc_concept[NAMESPACE],
+                to_loc_concept.get(IDENTIFIER),
+                to_loc_concept.get(NAME),
             )
         else:
             t = (TRANSLOCATION,)
         result.append(t)
 
     if location:
-        location_name = location.get(NAME)
-        location_identifier = location.get(IDENTIFIER)
-
         t = (
             LOCATION,
             location[NAMESPACE],
-            location_name or location_identifier,
+            location.get(IDENTIFIER),
+            location.get(NAME),
         )
         result.append(t)
 
@@ -327,3 +297,23 @@ def get_corresponding_pickle_path(path: str) -> str:
     :param path: A path to a BEL file.
     """
     return '{path}.pickle'.format(path=path)
+
+
+def citation_dict(*, db: str, db_id: str, db_name: Optional[str] = None, **kwargs):
+    """Make a citation dictionary."""
+    return CitationDict(db=db, db_id=db_id, db_name=db_name, **kwargs)
+
+
+class CitationDict(dict):
+    """A dictionary describing a citation."""
+
+    def __init__(self, db: str, db_id: str, *, db_name: Optional[str] = None, **kwargs):
+        super().__init__()
+        self[CITATION_DB] = db
+        self[CITATION_IDENTIFIER] = db_id
+        if db_name is not None:
+            self[CITATION_DB_NAME] = db_name
+        self.update(kwargs)
+
+    def __hash__(self):
+        return hash((self[CITATION_DB], self[CITATION_IDENTIFIER]))
