@@ -14,7 +14,6 @@ from pybel import (
     BELGraph, from_bel_script, from_bel_script_url, from_bytes, from_nodelink, from_nodelink_file, from_pickle,
     to_bel_script_lines, to_bytes, to_csv, to_graphml, to_gsea, to_nodelink, to_nodelink_file, to_pickle, to_sif,
 )
-from pybel.io.line_utils import parse_definitions
 from pybel.config import PYBEL_MINIMUM_IMPORT_VERSION
 from pybel.constants import (
     ANNOTATIONS, CITATION, DECREASES, DIRECTLY_DECREASES, EVIDENCE, GRAPH_PYBEL_VERSION, INCREASES, RELATION,
@@ -29,7 +28,7 @@ from pybel.parser.exc import (
     BELSyntaxError, InvalidFunctionSemantic, MissingCitationException, MissingNamespaceRegexWarning,
 )
 from pybel.struct.summary import get_syntax_errors
-from pybel.testing.cases import TemporaryCacheClsMixin
+from pybel.testing.cases import TemporaryCacheClsMixin, TemporaryCacheMixin
 from pybel.testing.constants import (
     test_bel_isolated, test_bel_misordered, test_bel_simple, test_bel_slushy, test_bel_thorough, test_bel_with_obo,
 )
@@ -433,12 +432,12 @@ class TestRandom(unittest.TestCase):
             )
 
 
-class TestNomenclature(unittest.TestCase):
+class TestNomenclature(TemporaryCacheMixin):
     """Test that `BEP-0008 nomenclature <http://bep.bel.bio/published/BEP-0008.html>`_ gets validated properly."""
 
     def test_bep_0008(self):
         """Test parsing works right"""
-        graph = from_bel_script(test_bel_with_obo)
+        graph = from_bel_script(test_bel_with_obo, manager=self.manager)
         self.assertIn('hgnc', graph.namespace_pattern)
         self.assertEqual(r'\d+', graph.namespace_pattern['hgnc'])
 
