@@ -2,8 +2,6 @@
 
 """Tests for interchange with JGIF."""
 
-from __future__ import unicode_literals
-
 import json
 import logging
 import sys
@@ -11,10 +9,10 @@ import unittest
 
 from pybel import from_cbn_jgif, to_jgif
 from pybel.constants import (
-    ACTIVITY, ANNOTATIONS, BEL_DEFAULT_NAMESPACE, CITATION, CITATION_REFERENCE, CITATION_TYPE, CITATION_TYPE_OTHER,
+    ACTIVITY, ANNOTATIONS, BEL_DEFAULT_NAMESPACE, CITATION, CITATION_IDENTIFIER, CITATION_DB, CITATION_TYPE_OTHER,
     CITATION_TYPE_PUBMED, DECREASES, DIRECTLY_INCREASES, EFFECT, EVIDENCE, MODIFIER, NAME, NAMESPACE, OBJECT, RELATION,
 )
-from pybel.dsl import Abundance, BiologicalProcess, ComplexAbundance, NamedComplexAbundance, Pathology, Protein, pmod
+from pybel.dsl import Abundance, BiologicalProcess, ComplexAbundance, NamedComplexAbundance, Pathology, Protein, ProteinModification
 from pybel.testing.constants import test_jgif_path
 from tests.constants import TestGraphMixin
 
@@ -23,7 +21,7 @@ logging.getLogger('pybel.parser').setLevel(20)
 calcium = Abundance('SCHEM', 'Calcium')
 calcineurin_complex = NamedComplexAbundance('SCOMP', 'Calcineurin Complex')
 foxo3 = Protein('HGNC', 'FOXO3')
-tcell_proliferation = BiologicalProcess('GOBP', 'CD8-positive, alpha-beta T cell proliferation')
+tcell_proliferation = BiologicalProcess('GO', 'CD8-positive, alpha-beta T cell proliferation')
 il15 = Protein('HGNC', 'IL15')
 il2rg = Protein('MGI', 'Il2rg')
 jgif_expected_nodes = {
@@ -35,11 +33,11 @@ jgif_expected_nodes = {
     il2rg,
     Protein('HGNC', 'CXCR6'),
     Protein('HGNC', 'IL15RA'),
-    BiologicalProcess('GOBP', 'lymphocyte chemotaxis'),
+    BiologicalProcess('GO', 'lymphocyte chemotaxis'),
     Protein('HGNC', 'IL2RG'),
     Protein('HGNC', 'ZAP70'),
     NamedComplexAbundance('SCOMP', 'T Cell Receptor Complex'),
-    BiologicalProcess('GOBP', 'T cell activation'),
+    BiologicalProcess('GO', 'T cell activation'),
     Protein('HGNC', 'CCL3'),
     Protein('HGNC', 'PLCG1'),
     Protein('HGNC', 'FASLG'),
@@ -73,7 +71,7 @@ jgif_expected_nodes = {
     Protein('SFAM', 'Chemokine Receptor Family'),
     ComplexAbundance([Protein('HGNC', 'CD8A'), Protein('HGNC', 'CD8B')]),
     ComplexAbundance([Protein('HGNC', 'CD8A'), Protein('HGNC', 'CD8B')]),
-    Protein('HGNC', 'PLCG1', variants=pmod('Ph', 'Tyr')),
+    Protein('HGNC', 'PLCG1', variants=ProteinModification('Ph', 'Tyr')),
     Protein('EGID', '21577'),
 }
 
@@ -82,8 +80,8 @@ jgif_expected_edges = [
         RELATION: DIRECTLY_INCREASES,
         EVIDENCE: 'NMDA-mediated influx of calcium led to activated of the calcium-dependent phosphatase calcineurin and the subsequent dephosphorylation and activation of the protein-tyrosine phosphatase STEP',
         CITATION: {
-            CITATION_TYPE: CITATION_TYPE_PUBMED,
-            CITATION_REFERENCE: '12483215'
+            CITATION_DB: CITATION_TYPE_PUBMED,
+            CITATION_IDENTIFIER: '12483215'
         },
         OBJECT: {MODIFIER: ACTIVITY, EFFECT: {NAMESPACE: BEL_DEFAULT_NAMESPACE, NAME: 'phos'}},
         ANNOTATIONS: {
@@ -95,8 +93,8 @@ jgif_expected_edges = [
         RELATION: DECREASES,
         EVIDENCE: "\"These data suggested that FOXO3 downregulates the accumulation of CD8 T cells in tissue specific fashion during an acute LCMV [lymphocytic choriomeningitis virus] infection.\" (p. 3)",
         CITATION: {
-            CITATION_TYPE: CITATION_TYPE_OTHER,
-            CITATION_REFERENCE: "22359505"
+            CITATION_DB: CITATION_TYPE_OTHER,
+            CITATION_IDENTIFIER: "22359505"
         },
         ANNOTATIONS: {
             'Species': {'10090': True},
@@ -107,8 +105,8 @@ jgif_expected_edges = [
         RELATION: DIRECTLY_INCREASES,
         EVIDENCE: "IL-15 utilizes ... the common cytokine receptor γ-chain (CD132) for signal transduction in lymphocytes",
         CITATION: {
-            CITATION_TYPE: CITATION_TYPE_OTHER,
-            CITATION_REFERENCE: "20335267"
+            CITATION_DB: CITATION_TYPE_OTHER,
+            CITATION_IDENTIFIER: "20335267"
         },
         OBJECT: {MODIFIER: ACTIVITY, EFFECT: {NAMESPACE: BEL_DEFAULT_NAMESPACE, NAME: 'cat'}},
         ANNOTATIONS: {
@@ -119,7 +117,7 @@ jgif_expected_edges = [
 
 
 class TestJgif(TestGraphMixin):
-    """Tests data interchange of """
+    """Tests data interchange of JGIF."""
 
     @unittest.skipIf(sys.platform.startswith("win"), "does not work on Windows")
     def test_jgif_interchange(self):
