@@ -4,47 +4,41 @@ from pybel.examples import sialic_acid_graph
 from pybel.examples.sialic_acid_example import cd33, cd33_phosphorylated, shp2, syk, trem2
 from pybel.manager.models import Edge, Namespace, Network
 from pybel.manager.query_manager import graph_from_edges
+from pybel.resources import CHEBI_URL, GO_URL, HGNC_URL
 from pybel.testing.cases import TemporaryCacheClsMixin
 from pybel.testing.mocks import mock_bel_resources
 
-chebi_url = 'https://arty.scai.fraunhofer.de/artifactory/bel/namespace/chebi/chebi-20170725.belns'
-
 
 class TestSeeding(TemporaryCacheClsMixin):
-    """This module tests the seeding functions in the query manager"""
+    """This module tests the seeding functions in the query manager."""
 
     @classmethod
     def setUpClass(cls):
-        """Adds the sialic acid subgraph for all query tests"""
-        super(TestSeeding, cls).setUpClass()
+        """Add the Sialic Acid subgraph for all query tests."""
+        super().setUpClass()
 
-        @mock_bel_resources
-        def insert(mock):
-            """Inserts the Sialic Acid Subgraph using the mock resources"""
-            cls.manager.insert_graph(sialic_acid_graph, store_parts=True)
-
-        insert()
+        with mock_bel_resources:
+            cls.manager.insert_graph(sialic_acid_graph)
 
     def test_namespace_existence(self):
-        a = 'https://arty.scai.fraunhofer.de/artifactory/bel/namespace/hgnc-human-genes/hgnc-human-genes-20170725.belns'
-        n = self.manager.session.query(Namespace).filter(Namespace.url == a).one()
+        """Check the sialic acid graph has the right namespaces, and they're uploaded properly."""
+        ns = self.manager.session.query(Namespace).filter(Namespace.url == HGNC_URL).one()
+        self.assertIsNotNone(ns)
 
-    def test_namespace_existence_b(self):
-        ns = self.manager.session.query(Namespace).filter(Namespace.url == chebi_url).one()
+        ns = self.manager.session.query(Namespace).filter(Namespace.url == CHEBI_URL).one()
+        self.assertIsNotNone(ns)
+
+        ns = self.manager.session.query(Namespace).filter(Namespace.url == GO_URL).one()
         self.assertIsNotNone(ns)
 
     def test_sialic_acid_in_node_store(self):
         r = 'sialic acid'
 
-        n = self.manager.get_namespace_entry(chebi_url, r)
+        n = self.manager.get_namespace_entry(CHEBI_URL, r)
         self.assertIsNotNone(n)
 
         self.assertEqual(r, n.name)
 
-    def test_namespace_existence_c(self):
-        a = 'https://arty.scai.fraunhofer.de/artifactory/bel/namespace/go-biological-process/go-biological-process-20170725.belns'
-        self.manager.session.query(Namespace).filter(Namespace.url == a).one()
-
     def test_network_existence(self):
         networks = self.manager.session.query(Network).all()
 
@@ -57,16 +51,12 @@ class TestSeeding(TemporaryCacheClsMixin):
 
     def test_seed_by_pmid(self):
         pmids = ['26438529']
-
         edges = self.manager.query_edges_by_pubmed_identifiers(pmids)
-
-        self.assertLess(0, len(edges))
+        self.assertLessEqual(1, len(edges))
 
     def test_seed_by_pmid_no_result(self):
         missing_pmids = ['11111']
-
         edges = self.manager.query_edges_by_pubmed_identifiers(missing_pmids)
-
         self.assertEqual(0, len(edges))
 
     def test_seed_by_induction_raise(self):
