@@ -8,60 +8,56 @@ import re
 import unittest
 from pathlib import Path
 
+from bel_resources.constants import ANNOTATION_URL_FMT, NAMESPACE_URL_FMT
 from pybel.parser import MetadataParser
 from pybel.parser.exc import (
     InvalidMetadataException, RedefinedAnnotationError, RedefinedNamespaceError, VersionFormatWarning,
 )
+from pybel.resources import HGNC_URL
 from pybel.testing.cases import FleetingTemporaryCacheMixin
-from pybel.testing.constants import test_an_1, test_ns_1, test_ns_nocache_path
+from pybel.testing.constants import test_an_1, test_ns_1
 from pybel.testing.mocks import mock_bel_resources
-from tests.constants import (
-    HGNC_KEYWORD, HGNC_URL, MESH_DISEASES_KEYWORD, MESH_DISEASES_URL, help_check_hgnc,
-)
+from tests.constants import HGNC_KEYWORD, MESH_DISEASES_KEYWORD, MESH_DISEASES_URL, help_check_hgnc
 
 logging.getLogger("requests").setLevel(logging.WARNING)
 
 
+LOCAL_TEST_PATH = os.path.expanduser("~/dev/pybel/src/pybel/testing/resources/belns/hgnc-names.belns")
+
+
 class TestParseMetadata(FleetingTemporaryCacheMixin):
     def setUp(self):
         super(TestParseMetadata, self).setUp()
         self.parser = MetadataParser(manager=self.manager)
 
-    def help_test_local_annotation(self, annotation: str) -> None:
+    def _help_test_local_annotation(self, annotation: str) -> None:
         """Check that the annotation is defined locally."""
         self.assertTrue(self.parser.has_annotation(annotation))
         self.assertNotIn(annotation, self.parser.annotation_to_term)
         self.assertFalse(self.parser.has_enumerated_annotation(annotation))
-        self.assertNotIn(annotation, self.parser.annotation_pattern)
+        self.assertNotIn(annotation, self.parser.annotation_to_pattern)
         self.assertFalse(self.parser.has_regex_annotation(annotation))
         self.assertIn(annotation, self.parser.annotation_to_local)
         self.assertTrue(self.parser.has_local_annotation(annotation))
 
-    def test_namespace_nocache(self):
-        """Checks namespace is loaded into parser but not cached"""
-        s = 'DEFINE NAMESPACE TESTNS3 AS URL "{}"'.format(test_ns_nocache_path)
-        self.parser.parseString(s)
-        self.assertIn('TESTNS3', self.parser.namespace_to_term)
-        self.assertEqual(0, len(self.manager.list_namespaces()))
-
     @mock_bel_resources
     def test_namespace_name_persistience(self, mock_get):
-        """Tests that a namespace defined by a URL can't be overwritten by a definition by another URL"""
-        s = 'DEFINE NAMESPACE {} AS URL "{}"'.format(HGNC_KEYWORD, HGNC_URL)
+        """Test that a namespace defined by a URL can't be overwritten by a definition by another URL."""
+        s = NAMESPACE_URL_FMT.format(HGNC_KEYWORD, HGNC_URL)
         self.parser.parseString(s)
-        help_check_hgnc(self, self.parser.namespace_to_term)
+        help_check_hgnc(self, self.parser.namespace_to_term_to_encoding)
 
-        s = 'DEFINE NAMESPACE {} AS URL "{}"'.format(HGNC_KEYWORD, 'XXXXX')
+        s = NAMESPACE_URL_FMT.format(HGNC_KEYWORD, 'XXXXX')
         with self.assertRaises(RedefinedNamespaceError):
             self.parser.parseString(s)
 
-        help_check_hgnc(self, self.parser.namespace_to_term)
+        help_check_hgnc(self, self.parser.namespace_to_term_to_encoding)
 
     @mock_bel_resources
     def test_annotation_name_persistience_1(self, mock_get):
-        """Tests that an annotation defined by a URL can't be overwritten by a definition by a list"""
+        """Test that an annotation defined by a URL can't be overwritten by a definition by a list."""
 
-        s = 'DEFINE ANNOTATION {} AS URL "{}"'.format(MESH_DISEASES_KEYWORD, MESH_DISEASES_URL)
+        s = ANNOTATION_URL_FMT.format(MESH_DISEASES_KEYWORD, MESH_DISEASES_URL)
         self.parser.parseString(s)
         self.assertIn(MESH_DISEASES_KEYWORD, self.parser.annotation_to_term)
 
@@ -77,41 +73,40 @@ class TestParseMetadata(FleetingTemporaryCacheMixin):
         """Tests that an annotation defined by a list can't be overwritten by a definition by URL"""
         s = 'DEFINE ANNOTATION TextLocation AS LIST {"Abstract","Results","Legend","Review"}'
         self.parser.parseString(s)
-        self.help_test_local_annotation('TextLocation')
+        self._help_test_local_annotation('TextLocation')
 
-        s = 'DEFINE ANNOTATION TextLocation AS URL "{}"'.format(MESH_DISEASES_URL)
+        s = ANNOTATION_URL_FMT.format('TextLocation', MESH_DISEASES_URL)
         with self.assertRaises(RedefinedAnnotationError):
             self.parser.parseString(s)
 
-        self.help_test_local_annotation('TextLocation')
+        self._help_test_local_annotation('TextLocation')
         self.assertIn('Abstract', self.parser.annotation_to_local['TextLocation'])
 
     def test_underscore(self):
         """Tests that an underscore is a valid character in an annotation name"""
         s = 'DEFINE ANNOTATION Text_Location AS LIST {"Abstract","Results","Legend","Review"}'
         self.parser.parseString(s)
-        self.help_test_local_annotation('Text_Location')
+        self._help_test_local_annotation('Text_Location')
 
     @mock_bel_resources
     def test_control_compound(self, mock_get):
         text_location = 'TextLocation'
         lines = [
-            'DEFINE ANNOTATION {} AS URL "{}"'.format(MESH_DISEASES_KEYWORD, MESH_DISEASES_URL),
-            'DEFINE NAMESPACE {} AS URL "{}"'.format(HGNC_KEYWORD, HGNC_URL),
+            ANNOTATION_URL_FMT.format(MESH_DISEASES_KEYWORD, MESH_DISEASES_URL),
+            NAMESPACE_URL_FMT.format(HGNC_KEYWORD, HGNC_URL),
             'DEFINE ANNOTATION TextLocation AS LIST {"Abstract","Results","Legend","Review"}'
         ]
         self.parser.parse_lines(lines)
 
         self.assertIn(MESH_DISEASES_KEYWORD, self.parser.annotation_to_term)
-        self.assertIn(HGNC_KEYWORD, self.parser.namespace_to_term)
-        self.help_test_local_annotation(text_location)
+        self.assertIn(HGNC_KEYWORD, self.parser.namespace_to_term_to_encoding)
+        self._help_test_local_annotation(text_location)
 
-    @unittest.skipUnless('PYBEL_BASE' in os.environ, "Need local files to test local files")
+    @unittest.skipUnless(os.path.exists(LOCAL_TEST_PATH), "Need local files to test local files")
     def test_squiggly_filepath(self):
-        line = 'DEFINE NAMESPACE {} AS URL "~/dev/pybel/src/pybel/testing/resources/belns/hgnc-human-genes.belns"'.format(
-            HGNC_KEYWORD)
+        line = NAMESPACE_URL_FMT.format(HGNC_KEYWORD, LOCAL_TEST_PATH)
         self.parser.parseString(line)
-        help_check_hgnc(self, self.parser.namespace_to_term)
+        help_check_hgnc(self, self.parser.namespace_to_term_to_encoding)
 
     def test_document_metadata_exception(self):
         s = 'SET DOCUMENT InvalidKey = "nope"'
@@ -133,7 +128,7 @@ class TestParseMetadata(FleetingTemporaryCacheMixin):
     @mock_bel_resources
     def test_parse_namespace_url_file(self, mock):
         """Tests parsing a namespace by file URL"""
-        s = 'DEFINE NAMESPACE TESTNS1 AS URL "{}"'.format(test_ns_1)
+        s = NAMESPACE_URL_FMT.format('TESTNS1', test_ns_1)
         self.parser.parseString(s)
 
         expected_values = {
@@ -144,20 +139,18 @@ class TestParseMetadata(FleetingTemporaryCacheMixin):
             'TestValue5': {'O'}
         }
 
-        self.assertIn('TESTNS1', self.parser.namespace_to_term)
+        self.assertIn('TESTNS1', self.parser.namespace_to_term_to_encoding)
 
         for k, values in expected_values.items():
-            self.assertIn(k, self.parser.namespace_to_term['TESTNS1'])
-            self.assertEqual(set(values), set(self.parser.namespace_to_term['TESTNS1'][k]))
+            k = (None, k)
+            self.assertIn(k, self.parser.namespace_to_term_to_encoding['TESTNS1'])
+            self.assertEqual(set(values), set(self.parser.namespace_to_term_to_encoding['TESTNS1'][k]))
 
     def test_parse_annotation_url_file(self):
         """Tests parsing an annotation by file URL"""
         keyword = 'TESTAN1'
         url = Path(test_an_1).as_uri()
-        line = 'DEFINE ANNOTATION {keyword} AS URL "{url}"'.format(
-            keyword=keyword,
-            url=url,
-        )
+        line = ANNOTATION_URL_FMT.format(keyword, url)
         self.parser.parseString(line)
 
         expected_values = {
@@ -182,7 +175,7 @@ class TestParseMetadata(FleetingTemporaryCacheMixin):
         s = 'DEFINE NAMESPACE dbSNP AS PATTERN "rs[0-9]*"'
         self.parser.parseString(s)
 
-        self.assertNotIn('dbSNP', self.parser.namespace_to_term)
+        self.assertNotIn('dbSNP', self.parser.namespace_to_term_to_encoding)
         self.assertIn('dbSNP', self.parser.namespace_to_pattern)
         self.assertEqual(re.compile('rs[0-9]*'), self.parser.namespace_to_pattern['dbSNP'])
 
