@@ -2,12 +2,17 @@
 
 """Tests for data structures in PyBEL."""
 
+import os
+import tempfile
 import unittest
 from io import StringIO
 
+import pybel
+import pybel.examples
 from pybel import BELGraph
-from pybel.constants import CITATION_REFERENCE, CITATION_TYPE, CITATION_TYPE_PUBMED
+from pybel.constants import CITATION_DB, CITATION_IDENTIFIER, CITATION_TYPE_PUBMED
 from pybel.dsl import hgvs, protein
+from pybel.io.api import InvalidExtensionError
 from pybel.testing.utils import n
 
 
@@ -27,11 +32,8 @@ class TestGraphProperties(unittest.TestCase):
             self.disclaimer
         ) = [n() for _ in range(8)]
 
-    def help_test_metadata(self, graph):
-        """Help test the right metadata got in the graph.
-
-        :type graph: BELGraph
-        """
+    def _help_test_metadata(self, graph: BELGraph) -> None:
+        """Help test the right metadata got in the graph."""
         self.assertEqual(self.name, graph.name)
         self.assertEqual(self.version, graph.version)
         self.assertEqual(self.description, graph.description)
@@ -55,7 +57,7 @@ class TestGraphProperties(unittest.TestCase):
             copyright=self.copyrights,
             disclaimer=self.disclaimer
         )
-        self.help_test_metadata(graph)
+        self._help_test_metadata(graph)
 
     def test_name(self):
         """Test setting of metadata through attributes."""
@@ -70,7 +72,7 @@ class TestGraphProperties(unittest.TestCase):
         graph.copyright = self.copyrights
         graph.disclaimer = self.disclaimer
 
-        self.help_test_metadata(graph)
+        self._help_test_metadata(graph)
 
 
 class TestStruct(unittest.TestCase):
@@ -93,6 +95,8 @@ class TestStruct(unittest.TestCase):
         test_str = """Test v0.0.0
 Number of Nodes: 1
 Number of Edges: 0
+Number of Citations: 0
+Number of Authors: 0
 Network Density: 0.00E+00
 Number of Components: 1
 Number of Warnings: 0"""
@@ -144,10 +148,10 @@ class TestGetGraphProperties(unittest.TestCase):
 
         self.assertIsNotNone(citation)
         self.assertIsInstance(citation, dict)
-        self.assertIn(CITATION_TYPE, citation)
-        self.assertEqual(CITATION_TYPE_PUBMED, citation[CITATION_TYPE])
-        self.assertIn(CITATION_REFERENCE, citation)
-        self.assertEqual(test_pmid, citation[CITATION_REFERENCE])
+        self.assertIn(CITATION_DB, citation)
+        self.assertEqual(CITATION_TYPE_PUBMED, citation[CITATION_DB])
+        self.assertIn(CITATION_IDENTIFIER, citation)
+        self.assertEqual(test_pmid, citation[CITATION_IDENTIFIER])
 
         evidence = self.graph.get_edge_evidence(test_source, test_target, test_key)
 
@@ -181,20 +185,6 @@ class TestGetGraphProperties(unittest.TestCase):
         annotations = self.graph.get_edge_annotations(test_source, test_target, key)
         self.assertIsNone(annotations)
 
-    def test_get_node_properties(self):
-        """Test looking up node properties."""
-        test_name = n()
-        test_identifier = n()
-
-        node = protein(namespace='TEST', name=test_name, identifier=test_identifier)
-        self.graph.add_node_from_data(node)
-
-        self.assertIsNone(self.graph.get_node_description(node))
-
-        test_description = n()
-        self.graph.set_node_description(node, test_description)
-        self.assertEqual(test_description, self.graph.get_node_description(node))
-
     def test_add_node_with_variant(self):
         """Test that the identifier is carried through to the child."""
         graph = BELGraph()
@@ -205,3 +195,20 @@ class TestGetGraphProperties(unittest.TestCase):
         graph.add_node_from_data(node)
 
         self.assertEqual(2, graph.number_of_nodes())
+
+
+class TestExtensionIO(unittest.TestCase):
+    def test_io(self):
+        with tempfile.TemporaryDirectory() as directory:
+            path = os.path.join(directory, 'ampk.bel.nodelink.json')
+            pybel.dump(pybel.examples.ampk_graph, path)
+            self.assertTrue(os.path.exists(path))
+            new_graph = pybel.load(path)
+            self.assertIsNotNone(new_graph)
+
+    def test_invalid_io(self):
+        with tempfile.TemporaryDirectory() as directory:
+            path = os.path.join(directory, 'ampk.bel.invalid.json')
+            with self.assertRaises(InvalidExtensionError):
+                pybel.dump(pybel.examples.ampk_graph, path)
+            self.assertFalse(os.path.exists(path))
