@@ -119,7 +119,7 @@ class TestRandom(unittest.TestCase):
             result,
             graph,
             number_edges_remaining=5,
-            no_grow={1, 2, 3},
+            node_blacklist={1, 2, 3},
         )
 
         self.assertNotIn(3, result)
@@ -132,4 +132,4 @@ class TestRandomPath(unittest.TestCase):
         """Test getting random paths doesn't crash."""
         for graph in (sialic_acid_graph, statin_graph):
             for _ in range(100):
-                get_random_path(graph)
+                get_random_path(graph.copy())
