@@ -4,7 +4,7 @@
 
 import unittest
 
-from pybel.constants import ABUNDANCE, FUNCTION, IDENTIFIER, NAME, NAMESPACE
+from pybel.constants import ABUNDANCE, CONCEPT, FUNCTION, IDENTIFIER, NAME, NAMESPACE
 from pybel.dsl import Abundance
 from pybel.testing.utils import n
 from pybel.tokens import _simple_po_to_dict
@@ -21,8 +21,10 @@ class TestRecover(unittest.TestCase):
             Abundance(namespace=namespace, name=name),
             _simple_po_to_dict({
                 FUNCTION: ABUNDANCE,
-                NAMESPACE: namespace,
-                NAME: name,
+                CONCEPT: {
+                    NAMESPACE: namespace,
+                    NAME: name,
+                },
             })
         )
 
@@ -30,9 +32,11 @@ class TestRecover(unittest.TestCase):
             Abundance(namespace=namespace, name=name, identifier=identifier),
             _simple_po_to_dict({
                 FUNCTION: ABUNDANCE,
-                NAMESPACE: namespace,
-                NAME: name,
-                IDENTIFIER: identifier,
+                CONCEPT: {
+                    NAMESPACE: namespace,
+                    NAME: name,
+                    IDENTIFIER: identifier,
+                },
             })
         )
 
@@ -40,13 +44,17 @@ class TestRecover(unittest.TestCase):
             Abundance(namespace=namespace, identifier=identifier),
             _simple_po_to_dict({
                 FUNCTION: ABUNDANCE,
-                NAMESPACE: namespace,
-                IDENTIFIER: identifier,
+                CONCEPT: {
+                    NAMESPACE: namespace,
+                    IDENTIFIER: identifier,
+                },
             })
         )
 
         with self.assertRaises(ValueError):
             _simple_po_to_dict({
                 FUNCTION: ABUNDANCE,
-                NAMESPACE: namespace,
+                CONCEPT: {
+                    NAMESPACE: namespace,
+                },
             })
